| Title: | Neutrosophic Analysis of Split-Plot and Strip-Plot Designs |
|---|---|
| Description: | Provides methods for Neutrosophic Analysis of Variance (NANOVA) for split-plot and strip-plot experimental designs using interval-valued observations. The package computes neutrosophic sums of squares, mean squares, interval-valued F-statistics, significance tests, and Least Significant Difference (LSD) based multiple comparisons for main plot, sub plot, horizontal factor, vertical factor, and interaction effects. For crisp data, users may provide identical lower and upper response values to obtain results equivalent to classical analysis of variance. The basic idea of neutrosophic statistics is obtained from Smarandache (2014) <https://fs.unm.edu/NeutrosophicStatistics.pdf>, while the analysis procedures implemented in this package are newly developed. |
| Authors: | Boyina Devi Priyanka [aut, ctb], Neethu R.S [aut, ctb], Cini Varghese [aut, ctb], Mohd Harun [aut, ctb], Anindita Datta [aut, ctb], Susheel kumar [aut, ctb], Vinaykumar L.N. [aut, cre] |
| Maintainer: | Vinaykumar L.N. <[email protected]> |
| License: | GPL-3 |
| Version: | 0.0.1 |
| Built: | 2026-06-22 19:31:10 UTC |
| Source: | https://github.com/cran/NeutroSplitStripAnalysis |
Performs Neutrosophic Analysis of Variance (NANOVA) for split-plot designs using interval-valued observations. The function provides neutrosophic ANOVA tables, interval-valued F-tests, significance tests, and Least Significant Difference (LSD) based multiple comparisons. For crisp data, users may provide identical lower and upper response values to obtain results equivalent to classical split-plot ANOVA.
SplitPlotDnsANOVA(Lower_y, Upper_y, design, alpha = 0.05, verbose = FALSE)SplitPlotDnsANOVA(Lower_y, Upper_y, design, alpha = 0.05, verbose = FALSE)
Lower_y |
A matrix containing the lower values of the response variable. |
Upper_y |
A matrix containing the upper values of the response variable. |
design |
A data frame containing three columns corresponding to replication, main plot treatments, and sub plot treatments, respectively. |
alpha |
Significance level used for hypothesis testing and LSD-based multiple comparisons. Default is 0.05. |
verbose |
Logical. If TRUE, the neutrosophic ANOVA table, significance tests, LSD values, and multiple comparison results are displayed. Default is FALSE. |
A list containing:
Neutrosophic ANOVA table containing sources of variation, degrees of freedom, neutrosophic sums of squares, mean squares, F-statistics, and significance levels.
Neutrosophic LSD interval for main plot effects, returned only when the main plot effect is significant.
Neutrosophic LSD interval for sub plot effects, returned only when the sub plot effect is significant.
Neutrosophic LSD interval for interaction effects, returned only when the interaction effect is significant.
Pairwise neutrosophic comparisons among main plot treatment means.
Pairwise neutrosophic comparisons among sub plot treatment means.
Pairwise neutrosophic comparisons among interaction treatment means.
Lower_y <- matrix(c( 13.81,13.11,18.16, 18.54,19.84,28.43, 11.48,14.33,14.29, 14.50,15.99,21.19, 11.65,18.08,17.37, 11.78,12.46,17.21, 11.67,11.28,8.65, 18.81,16.27,21.46, 11.96,16.15,18.19, 10.34,11.28,16.91, 9.08,14.91,11.95, 11.04,10.80,6.48 ), ncol = 3, byrow = TRUE) Upper_y <- matrix(c( 17.19,21.89,23.44, 22.46,29.16,31.97, 19.72,22.07,22.71, 23.30,24.41,27.81, 18.35,22.92,20.43, 20.22,19.14,19.39, 14.13,17.72,18.35, 21.59,20.73,29.34, 19.84,24.85,26.81, 15.46,15.72,20.09, 17.92,20.09,17.85, 13.96,13.00,14.52 ), ncol = 3, byrow = TRUE) Rep <- factor(rep(paste0("R",1:4), each = 9)) MainPlot <- factor(rep(rep(paste0("M",1:3), each = 3), 4)) SubPlot <- factor(rep(paste0("S",1:3), 12)) design <- data.frame(Rep, MainPlot, SubPlot) result <- SplitPlotDnsANOVA(Lower_y = Lower_y, Upper_y = Upper_y, design = design, alpha = 0.05, verbose = TRUE)Lower_y <- matrix(c( 13.81,13.11,18.16, 18.54,19.84,28.43, 11.48,14.33,14.29, 14.50,15.99,21.19, 11.65,18.08,17.37, 11.78,12.46,17.21, 11.67,11.28,8.65, 18.81,16.27,21.46, 11.96,16.15,18.19, 10.34,11.28,16.91, 9.08,14.91,11.95, 11.04,10.80,6.48 ), ncol = 3, byrow = TRUE) Upper_y <- matrix(c( 17.19,21.89,23.44, 22.46,29.16,31.97, 19.72,22.07,22.71, 23.30,24.41,27.81, 18.35,22.92,20.43, 20.22,19.14,19.39, 14.13,17.72,18.35, 21.59,20.73,29.34, 19.84,24.85,26.81, 15.46,15.72,20.09, 17.92,20.09,17.85, 13.96,13.00,14.52 ), ncol = 3, byrow = TRUE) Rep <- factor(rep(paste0("R",1:4), each = 9)) MainPlot <- factor(rep(rep(paste0("M",1:3), each = 3), 4)) SubPlot <- factor(rep(paste0("S",1:3), 12)) design <- data.frame(Rep, MainPlot, SubPlot) result <- SplitPlotDnsANOVA(Lower_y = Lower_y, Upper_y = Upper_y, design = design, alpha = 0.05, verbose = TRUE)
Performs Neutrosophic Analysis of Variance (NANOVA) for strip-plot designs using interval-valued observations. The function provides neutrosophic ANOVA tables, interval-valued F-tests, significance tests, and Least Significant Difference (LSD) based multiple comparisons for horizontal factors, vertical factors, and their interaction effects. For crisp data, users may provide identical lower and upper response values to obtain results equivalent to classical strip-plot ANOVA.
StripPlotDnsANOVA(Lower_y, Upper_y, design, alpha = 0.05, verbose = FALSE)StripPlotDnsANOVA(Lower_y, Upper_y, design, alpha = 0.05, verbose = FALSE)
Lower_y |
A matrix containing the lower values of the response variable. |
Upper_y |
A matrix containing the upper values of the response variable. |
design |
A data frame containing three columns corresponding to replication, horizontal factor treatments, and vertical factor treatments, respectively. |
alpha |
Significance level used for hypothesis testing and LSD-based multiple comparisons. Default is 0.05. |
verbose |
Logical. If TRUE, the neutrosophic ANOVA table, significance tests, LSD values, and multiple comparison results are displayed. Default is FALSE. |
A list containing:
Neutrosophic ANOVA table containing sources of variation, degrees of freedom, neutrosophic sums of squares, mean squares, F-statistics, and significance levels.
Neutrosophic LSD interval for horizontal factor effects, returned only when the horizontal factor effect is significant.
Neutrosophic LSD interval for vertical factor effects, returned only when the vertical factor effect is significant.
Neutrosophic LSD interval for horizontal x vertical interaction effects, returned only when the interaction effect is significant.
Pairwise neutrosophic comparisons among horizontal factor treatment means.
Pairwise neutrosophic comparisons among vertical factor treatment means.
Pairwise neutrosophic comparisons among horizontal x vertical treatment combinations.
Lower_y <- matrix(c( 10,12, 11,13, 12,14, 13,15, 11,12, 12,13 ), nrow = 6, byrow = TRUE) Upper_y <- matrix(c( 12,14, 13,15, 14,16, 15,17, 13,14, 14,15 ), nrow = 6, byrow = TRUE) # Strip-plot design # 2 Replications x 3 Horizontal Factors x 2 Vertical Factors Rep <- factor(rep(c("R1","R2"), each = 6)) Horizontal <- factor(rep(c("H1","H2","H3"), each = 2, times = 2)) Vertical <- factor(rep(c("S1","S2"), times = 6)) design <- data.frame(Rep, Horizontal, Vertical) result <- StripPlotDnsANOVA( Lower_y = Lower_y, Upper_y = Upper_y, design = design, alpha = 0.05, verbose = TRUE )Lower_y <- matrix(c( 10,12, 11,13, 12,14, 13,15, 11,12, 12,13 ), nrow = 6, byrow = TRUE) Upper_y <- matrix(c( 12,14, 13,15, 14,16, 15,17, 13,14, 14,15 ), nrow = 6, byrow = TRUE) # Strip-plot design # 2 Replications x 3 Horizontal Factors x 2 Vertical Factors Rep <- factor(rep(c("R1","R2"), each = 6)) Horizontal <- factor(rep(c("H1","H2","H3"), each = 2, times = 2)) Vertical <- factor(rep(c("S1","S2"), times = 6)) design <- data.frame(Rep, Horizontal, Vertical) result <- StripPlotDnsANOVA( Lower_y = Lower_y, Upper_y = Upper_y, design = design, alpha = 0.05, verbose = TRUE )